@@ -196,9 +196,11 @@ static PyObject* alpha_calculation(PyObject *self, PyObject *args){
 	double K2 = 0;	
 	double m = 0;
 	double temp1, temp2, temp3;
+	double temp21, temp31;
+	double alpha911 = 0, alpha921 = 0;
 	double alpha91 = 0, alpha92 = 0;
 	double alpha81 = 0, alpha82 = 0;
-	double alpha71 = 0, alpha72 = 0;
+	double alpha71 = 0, alpha72 = 0;	
 	uint16_t temp71 = 0, temp72 = 0;
 	uint16_t temp81 = 0, temp82 = 0;
 	uint16_t temp91 = 0, temp92 = 0;	
@@ -232,6 +234,22 @@ static PyObject* alpha_calculation(PyObject *self, PyObject *args){
 			{
 				alpha91 = asin(temp2);//alpha91 = math.asin(temp2)
                 alpha92 = asin(temp3);//alpha92 = math.asin(temp3)
+				//Ver4 change start
+				temp21 = (K1 + temp2 + m) / (-K2);
+                temp31 = (K1 + temp3 + m) / (-K2);
+				if (fabs(temp21) <= 1)//if math.fabs(temp21) <= 1:
+				{
+					alpha911 = acos(temp21);//alpha911 = math.acos(temp21)	
+					if ((alpha91 > 0 && alpha911 > alpha91) || (alpha91 < 0 && alpha911 < alpha91))//:if (alpha91 > 0 and alpha911 > alpha91) or (alpha91 < 0 and alpha911 < alpha91):
+					alpha91 = alpha911; //alpha91 = alpha911
+				}
+				if (fabs(temp31) <= 1)//if math.fabs(temp31) <= 1:
+				{
+					alpha921 = acos(temp31);//alpha921 = math.acos(temp31)	
+					if ((alpha92 > 0 && alpha921 > alpha92) || (alpha92 < 0 && alpha921 < alpha92))//://if (alpha92 > 0 and alpha921 > alpha92) or (alpha92 < 0 and alpha921 < alpha92):
+					alpha92 = alpha921; //alpha92 = alpha921
+				}
+				//Ver4 change stop
 			}
 			else 
 			{
@@ -249,9 +267,15 @@ static PyObject* alpha_calculation(PyObject *self, PyObject *args){
         	continue;
 		}
 		//alpha81 = math.atan((K1+a8*math.sin(alpha91))/(K2+a8*math.cos(alpha91))) - alpha91
-		alpha81	= atan((K1 + a8 * sin(alpha91)) / (K2 + a8 * cos(alpha91))) - alpha91;
+		//alpha81	= atan((K1 + a8 * sin(alpha91)) / (K2 + a8 * cos(alpha91))) - alpha91;
         //alpha82 = math.atan((K1+a8*math.sin(alpha92))/(K2+a8*math.cos(alpha92))) - alpha92
-		alpha82	= atan((K1 + a8 * sin(alpha92)) / (K2 + a8 * cos(alpha92))) - alpha92;
+		//alpha82	= atan((K1 + a8 * sin(alpha92)) / (K2 + a8 * cos(alpha92))) - alpha92;
+		//Ver4 change start
+		//alpha81 = math.atan(-(K1+a8*math.sin(alpha91))/(-(K2+a8*math.cos(alpha91)))) - alpha91
+		alpha81	= atan(-(K1 + a8 * sin(alpha91)) / (-(K2 + a8 * cos(alpha91)))) - alpha91;
+        //alpha82 = math.atan(-(K1+a8*math.sin(alpha92))/(-(K2+a8*math.cos(alpha92)))) - alpha92
+		alpha82	= atan(-(K1 + a8 * sin(alpha92)) / (-(K2 + a8 * cos(alpha92)))) - alpha92;
+		//Ver4 change stop		
 		alpha71 = alpha91 + alpha81 - alpha987;
         alpha72 = alpha92 + alpha82 - alpha987;
 		//printf("alpha81 = ");
